**************************************************************
*Weghorst Keith, R. and Michael Bernhard. 2015. "From Formlessness to Structure: The Institutionalization of Competitive Party Systems in Africa" 
*File Contents: Replication file for MS Analysis (includes appendicies)
*Filename: weghorst_bernhard_cps_replication_2014.do
*Data Used: weghorst_bernhard_cps_replication_2014.dta
*File Output:f1_total&A&B_vio.gph; f2_typeavstypeb_overtime.gph; fA1_dv_distribution.gph; fA2_meanvolatility_overtime.pgh
*File Output (continued): ms_table2.txt, ms_table3.txt, appendix_tablea3.txt, appendix_tablea5.txt


**************************************************************


**Note to Users: 
*Thank you for downloading our replication data.  This file will allow you to repdroduce every table, 
*and figure presented in the text and in the online appendix.  In some cases, the figures in the text
*have been modified with Stata's graph editor for sylistic purposes, like adjusting shading density.  

*For simpler tables like descriptive statistics in the appendix, we did not instruct Stata to produce
*any additional files. This .do file does show such information within the Stata for illustration purposes.  
*We also do not provide replication of summary statistics we quote in the text--like median type A volatlity, but 
*these can be easily demontrated using this dataset.  Some fit statistics are not
*saved directly to the output .txt files and were entered manually into tables included in the manuscript.  These
*can be shown viewing individual estimation results rather than in nested form.

*Upon opening the .do file, please enter the file path to the location of the folder "cps_replication" where
*all outputs including tables and figures produced by the file will save. This is accomplished by removing the 
*asterisk before *cd "USERfilepath/cps_replication" and entering the file path.  You will also need to place 
*an asterisk in front of my directory (line 44).  

*Please contact us if you have any questions--corresponding author is Keith Weghorst at 
 *keith.r.weghorst@vanderbilt.edu 

*Keith and Michael



***********************
***********************
*Set-Up
***********************
clear
*cd "USERfilepath/cps_replication" 
*for example:
cd "/Users/keithweghorst/Desktop/cps_replication"
use weghorst_bernhard_cps_replication_2014.dta

***********************
*Package Installation
***********************
*We use the packages estout to tables to file and vioplot to generate figure 1.  
ssc install estout, replace
ssc install vioplot, replace


***********************
*Table 2: Nested Model in Text
***********************
eststo re1: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag  calorie_pcap_lag, re 
eststo re2: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag , re
eststo re3: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag  calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec, re 
eststo re4: quietly xtreg totalvol_100  multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag  calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2   after_colonialism contiguous_elections , re
eststo re5: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections    fhipolity2_dem_int , re
estout re1 re2 re3 re4 re5 using ms_table2.txt, replace cells(b(star fmt(2)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01)  legend label varlabels(_cons constant)    stats(N r2)
***********************
*Table 3: Comparing Total volatility, Type A volatility, & Type B volatility
***********************

eststo re5_typea: quietly xtreg typea_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections    fhipolity2_dem_int , re
eststo re5_typeb: quietly xtreg typeb_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections    fhipolity2_dem_int , re
estout re5 re5_typea re5_typeb using ms_table3.txt, replace cells(b(star fmt(2)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01)  legend label varlabels(_cons constant)    stats(N r2)

***********************
*Appendix A1-A2: 
***********************
sum totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections    fhipolity2_dem_int 
sum totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections    fhipolity2_dem_int if totalvol_100!=. &  multi_mwc!=. &  no_mwc !=. & rural_pop_pct_lag !=. & log_pwt_rgdpch_lag !=. & calorie_pcap_lag !=. & gdp_change_lag !=. & log_abs_wdi_infl_lag !=. & negative_value_flag!=. &  joint_mdm !=. &joint_mdm!=.n & parliamentarism !=. & govtcoalition_prevelec!=. &  british_colony!=. &  other_non_colony !=. & fh_ipolity2  !=. &   after_colonialism !=. &contiguous_elections    !=. & fhipolity2_dem_int 

***********************
*Appendix A3
***********************
***********************
*Appendix A3: FE models
***********************
eststo fe1: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag  calorie_pcap_lag, fe 
eststo fe2: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag , fe
eststo fe3: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag  calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec, fe 
eststo fe4: quietly xtreg totalvol_100  multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag  calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2   after_colonialism contiguous_elections , fe
eststo fe5: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections  fhipolity2_dem_int   , fe

***********************
*Appendix A3: Comparing models
***********************

estout fe1 re1 fe2 re2 fe3 re3 fe4 re4 fe5 re5 using appendix_tablea3.txt, replace cells(b(star fmt(2)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01)  legend label varlabels(_cons constant)    stats(N r2)


***********************
*Appendix: Hausman tests
***********************
*Note values arranged in table appearing in Appendix manually
hausman fe1 re1 ,sigmamore 
hausman fe2 re2, sigmamore
hausman fe3 re3, sigmamore
hausman fe4 re4, sigmamore
hausman fe5 re5, sigmamore

***********************
*Appendix A4
***********************
eststo re5_dom: quietly xtreg totalvol_100 multi_mwc no_mwc rural_pop_pct_lag log_pwt_rgdpch_lag calorie_pcap_lag gdp_change_lag log_abs_wdi_infl_lag negative_value_flag joint_mdm parliamentarism govtcoalition_prevelec british_colony other_non_colony fh_ipolity2    after_colonialism contiguous_elections    fhipolity2_dem_int dominant, re
estout re5 re5_dom using appendix_tablea4.txt, replace cells(b(star fmt(2)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01)  legend label varlabels(_cons constant)    stats(N r2)


***********************
*Figure 1: Distribution of volatility by types
***********************
vioplot totalvol_100 typea_100 typeb_100, ytitle(Legislative Volatility [0,100])  
graph save f1_total&A&B_vio.gph, replace

**Note: We changed some of the shading manually in the graph edit function.
    
***********************
*Figure 2: Volatility over time
***********************
twoway (line mean_typeb year) (line mean_typea year, lpattern(dot)) if year>1960 , ytitle(Volatility) ytitle(, size(small)) xtitle(Year) xtitle(, size(small)) title(Comparing Party Entry/Exit with Vote-Switching, size(medsmall)) legend(order(2 "Type A" 1 "Type B")) scheme(sj)
graph save f2_typeavstypeb_overtime.gph, replace
*Note: We utilized the year cap because this observation (Benin 1960) was listwise deleted in all analyses due to data coverage

***********************
*Figure A.1: Distribution of observations across time
***********************

histogram year, bin(15) percent kdensity ytitle(% of Volatility Observations) ytitle(, size(small)) xtitle(Distribution of Volatility Observations Over Time) xtitle(, size(medsmall)) note(With Kernel-Density plot overlay, size(vsmall) position(5))
graph save fA1_dv_distribution.gph, replace



***********************
*Figure A.2: Mean Total Volatility over time
***********************

twoway (line mean_totalvol year), ytitle(Mean Volatility (Total Pedersen)) ytitle(, size(small)) xtitle(Year) xtitle(, size(small)) title(Party System Volatility in Africa Over Time, size(medsmall))
graph save fA2_meanvolatility_overtime.gph, replace


